@@ -22,13 +22,16 @@ import tempfile
 # from apparmor.easyprof import AppArmorException, error
 # or apparmor.common ?
 
-# TODO: again, move this into the common library
-apparmor_fs = "/sys/kernel/security/apparmor"
+#
+# IMPORTANT: see end of this file for changing various default settings
+#
 
 #
 # TODO: move this out to the common library
 #
 #from apparmor import AppArmorException
+
+
 class AppArmorException(Exception):
     '''This class represents AppArmor exceptions'''
     def __init__(self, value):
@@ -41,8 +44,11 @@ class AppArmorException(Exception):
 #
 
 #
-# TODO: move this out to a utilities library
+# TODO: move these out to a utilities library
 #
+apparmor_fs = "/sys/kernel/security/apparmor"
+
+
 def error(out, exit_code=1, do_exit=True):
     '''Print error message and exit'''
     try:
@@ -53,28 +59,30 @@ def error(out, exit_code=1, do_exit=True):
     if do_exit:
         sys.exit(exit_code)
 
-#
-# TODO: move this to a utilities library
-#
-def load_profile(profile, parser="/sbin/apparmor_parser", args=['-r', '--write-cache']):
+
+def load_profile(profile, parser="/sbin/apparmor_parser",
+                 args=['-r', '--write-cache']):
+    '''Load individual profile into the kernel'''
 
     if not os.path.exists(parser):
         rc, parser = easyprof.cmd(['which', 'apparmor_parser'])
         if rc != 0:
-            raise AppArmorException("Could not find apparmor_parser. Skipping load")
+            raise AppArmorException("Could not find apparmor_parser. " +
+                                    "Skipping load")
 
     command = [parser]
     command.extend(args)
     command.append(profile)
     rc, output = easyprof.cmd(command)
     if rc != 0:
-        raise AppArmorException("policy load failed with errno %d: %s" %(rc, output))
+        raise AppArmorException("policy load failed with errno %d: %s" %
+                                (rc, output))
     return (rc, output)
 
-#
-# TODO: move this to a utilities library
-#
-def load_profiles(profiles, parser="/sbin/apparmor_parser", args=['-r', '--write-cache']):
+
+def load_profiles(profiles, parser="/sbin/apparmor_parser",
+                  args=['-r', '--write-cache']):
+    '''Load list of profiles into the kernel'''
 
     # it's possible we can be passed an empty list, be forgiving
     if len(profiles) == 0:
@@ -83,21 +91,21 @@ def load_profiles(profiles, parser="/sbin/apparmor_parser", args=['-r', '--write
     if not os.path.exists(parser):
         rc, parser = easyprof.cmd(['which', 'apparmor_parser'])
         if rc != 0:
-            raise AppArmorException("Could not find apparmor_parser. Skipping load")
+            raise AppArmorException("Could not find apparmor_parser. " +
+                                    "Skipping load")
 
     command = [parser]
     command.extend(args)
     command.extend(profiles)
     rc, output = easyprof.cmd(command)
     if rc != 0:
-        raise AppArmorException("policy load failed with errno %d: %s" %(rc, output))
+        raise AppArmorException("policy load failed with errno %d: %s" %
+                                (rc, output))
     return (rc, output)
 
-#
-# TODO: move this to a utilities library
-#
+
 def unload_profile(profile):
-    '''unload a profile name (not a filename) from the kernel'''
+    '''Unload a profile name (not a filename) from the kernel'''
 
     apparmor_remove = os.path.join(apparmor_fs, ".remove")
     try:
@@ -107,11 +115,9 @@ def unload_profile(profile):
         if e.errno != errno.ENOENT:
             raise
 
-#
-# TODO: move this to a utilities library
-#
+
 def unload_profiles(profiles):
-    '''unload a list of profile name (not filenames) from the kernel'''
+    '''Unload a list of profile names (not filenames) from the kernel'''
 
     apparmor_remove = os.path.join(apparmor_fs, ".remove")
     for profile in profiles:
@@ -121,12 +127,14 @@ def unload_profiles(profiles):
         except (OSError, IOError) as e:
             if e.errno != errno.ENOENT:
                 raise
+#
+# End utils
+#
+
 
-#
-# adjust easyprof output_policy to behave like this
-#
 def output_policy(easyp, params, count, destdir, force=True):
     '''Output policy'''
+    # TODO: Adjust easyprof output_policy to behave like this
     policy = easyp.gen_policy(**params)
     out_fn = None
     if not destdir:
@@ -139,12 +147,12 @@ def output_policy(easyp, params, count, destdir, force=True):
             out_fn = AppName(rawname=params['profile_name'])
         #elif 'binary' in params:
         #    out_fn = params['binary']
-        else: # should not ever reach this
+        else:  # should not ever reach this
             raise AppArmorException("Could not determine output filename")
 
         # Generate an absolute path, convertng any path delimiters to '.'
         out_fn = os.path.join(destdir, out_fn.profilename)
-        # we differ here in that we want to overwrite if exists
+        # We differ here in that we want to overwrite if exists
         if not force and os.path.exists(out_fn):
             raise AppArmorException("'%s' already exists" % out_fn)
 
@@ -164,6 +172,7 @@ def output_policy(easyp, params, count, destdir, force=True):
 
     return out_fn
 
+
 def walk_up(path):
     while True:
         yield path
@@ -172,13 +181,18 @@ def walk_up(path):
             return
         path = newpath
 
-def get_package_manifest(hooklink, pkg):
-    '''follow a click hook manifest symlink and return the main package manifest location'''
 
-    json_dir = os.path.realpath(os.path.normpath(os.path.join(os.path.dirname(hooklink), os.readlink(hooklink))))
+def get_package_manifest(hooklink, pkg):
+    '''Follow a click hook manifest symlink and return the main package
+       manifest location.
+    '''
+
+    json_dir = os.path.realpath(os.path.normpath(os.path.join(
+                                                 os.path.dirname(hooklink),
+                                                 os.readlink(hooklink))))
     manifest_name = "%s.manifest" % pkg
 
-    # walk up the tree to find the .click directory, then grab
+    # Walk up the tree to find the .click directory, then grab
     # info/manifest from below that
     for path in walk_up(json_dir):
         info = os.path.join(path, ".click", "info")
@@ -186,45 +200,56 @@ def get_package_manifest(hooklink, pkg):
         if os.path.isdir(info) and os.path.exists(manifest):
             return (manifest, path)
 
-    raise AppArmorException("Could not find click manifest '%s' from symlink '%s'" %(manifest_name, hooklink))
+    raise AppArmorException("Could not find click manifest '%s' from " +
+                            "symlink '%s'" % (manifest_name, hooklink))
+
 
 def get_click_dir(pkg_dir, pkg, ver):
+    '''Find click dir'''
     (p, last) = os.path.split(pkg_dir)
     if not ver == last:
-        raise AppArmorException("package version dir '%s' does not match expected '%s'" %(pkg_dir, ver))
+        raise AppArmorException("package version dir '%s' does not match " +
+                                "expected '%s'" % (pkg_dir, ver))
     (result, last) = os.path.split(p)
     if not pkg == last:
-        raise AppArmorException("package dir '%s' does not match expected '%s'" %(p, pkg))
+        raise AppArmorException("package dir '%s' does not match " +
+                                "expected '%s'" % (p, pkg))
     return result
 
-required_click_fields = ["name", "version"]
 
 def read_click_manifest(manifest):
+    '''Read click manifest'''
     f = open(manifest, "r")
     j = json.load(f)
     for field in required_click_fields:
         if not field in j:
-            raise AppArmorException("could not find required field '%s' in json" %(field))
+            raise AppArmorException("could not find required field '%s' " +
+                                    "in json" % (field))
     return j
 
+
 def read_apparmor_manifest(manifest, app):
+    '''Read AppArmor manifest from click package'''
     f = open(manifest, "r")
     j = json.load(f)
     if (len(j.keys()) == 1) and app in j:
         j = j[app]
-    # no fields are actually required, the framework transformation
+    # No fields are actually required, the framework transformation
     # should set sensible defaults if any/all are missing
     return j
 
+
 class ClickManifest(object):
     def __init__(self, clickhook):
-        (package, app, version) = parse_manifest_name(os.path.basename(clickhook))
+        (package, app, version) = parse_manifest_name(os.path.basename(
+                                                      clickhook))
         (click_manifest, pkg_dir) = get_package_manifest(clickhook, package)
         click_json = read_click_manifest(click_manifest)
         profile_json = read_apparmor_manifest(clickhook, app)
 
         #if not package == click_json['name']:
-        #    raise AppArmorException("package name '%s' in json doesn't match " %(field))
+        #    raise AppArmorException("package name '%s' in json doesn't " +
+        #                            "match " % (field))
 
         self.appname = click_json['name']
         self.version = click_json['version']
@@ -238,20 +263,23 @@ class ClickManifest(object):
         # overridden by the package manifest entry, if defined
         self.click_dir = get_click_dir(pkg_dir, package, version)
 
+
 class EasyprofManifest(object):
     def __init__(self):
         self.manifest = dict()
         self.manifest['profiles'] = dict()
 
     def add_profile(self, name, profile):
+        '''Add profile'''
         self.manifest['profiles'][name] = profile
 
+
 class AppName(object):
     _CLICK_PREFIX = "click_"
     _CLICK_SUFFIX = ".json"
 
     def __init__(self, clickname=None, profilename=None, rawname=None):
-        # verify valid click tuple name?
+        # Verify valid click tuple name?
         if clickname:
             self.clickname = clickname
         elif profilename:
@@ -263,28 +291,31 @@ class AppName(object):
 
     @property
     def clickname(self):
-        return "%s%s" %(self._clickname, self._CLICK_SUFFIX)
+        return "%s%s" % (self._clickname, self._CLICK_SUFFIX)
 
     @clickname.setter
     def clickname(self, clickname):
         if not clickname.endswith(self._CLICK_SUFFIX):
-            raise AppArmorException("invalid click manifest name '%s'" %(clickname))
+            raise AppArmorException("invalid click manifest name '%s'" %
+                                    (clickname))
 
         # strip the suffix off
         self._clickname = clickname[:-len(self._CLICK_SUFFIX)]
 
     @property
     def profilename(self):
-        return "%s%s" %(self._CLICK_PREFIX, self._clickname)
+        return "%s%s" % (self._CLICK_PREFIX, self._clickname)
 
     @profilename.setter
     def profilename(self, profilename):
         if not profilename.startswith(self._CLICK_PREFIX):
-            raise AppArmorException("invalid click profile name '%s'" %(profilename))
+            raise AppArmorException("invalid click profile name '%s'" %
+                                    (profilename))
 
-        # strip the click prefix off of the string
+        # Strip the click prefix off of the string
         self._clickname = profilename[len(self._CLICK_PREFIX):]
 
+
 class EasyprofProfile(object):
     def __init__(self, name):
         self.profile = dict()
@@ -328,15 +359,6 @@ class EasyprofProfile(object):
     def policyversion(self, version):
         self.profile['policy_version'] = version
 
-# ubuntu 13.10 tranformation function takes a click manifest json
-# structure as input and returns an aa-easyprof json manifest
-
-defaults_profile = {
-    'template': 'ubuntu-sdk',
-    'policy_version': '1.0',
-    'policy_vendor': 'ubuntu',
-    'policy_groups': list(),
-}
 
 def ubuntu_1310_transform(click_manifest):
     '''Ubuntu 13.10 SDK framework transformation function'''
@@ -344,7 +366,9 @@ def ubuntu_1310_transform(click_manifest):
 
     for p in click_manifest.profiles:
         newp = EasyprofProfile(p)
-        newname = "%s_%s_%s" %(click_manifest.appname, p, click_manifest.version)
+        newname = "%s_%s_%s" % (click_manifest.appname,
+                                p,
+                                click_manifest.version)
 
         profile = click_manifest.profiles[p]
         for default in defaults_profile:
@@ -376,45 +400,39 @@ def ubuntu_1310_transform(click_manifest):
     return m.manifest
 
 
-# these define the transformation funtions given a specific framework
-# definition in the ClickManifest file. This may need to grow more
-# complex depending on how the framework definition grows in click
-# packages
-
-framework_functions = {
-    "default": ubuntu_1310_transform,
-    "ubuntu-sdk-13.10": ubuntu_1310_transform,
-}
-
 def parse_manifest_name(name):
+    '''Parse a manifest name'''
     (n, ext) = os.path.splitext(name)
     if not ext == ".json":
-        raise AppArmorException("unable to parse manifest name %s" %(name))
+        raise AppArmorException("unable to parse manifest name %s" % (name))
 
     out = n.split("_")
     if len(out) != 3:
-        raise AppArmorException("unable to parse manifest name %s" %(name))
+        raise AppArmorException("unable to parse manifest name %s" % (name))
 
     return tuple(out)
 
-# takes a ClickManifest as input and returns an
-# aa-easyprof json structure
+
 def transform(click_manifest):
+    '''Transform click manifest into easyprof json'''
     if not click_manifest.framework in framework_functions:
-        raise AppArmorException("Unknown framework %s" %(click_manifest.framework))
+        raise AppArmorException("Unknown framework %s" %
+                                (click_manifest.framework))
 
     transform_function = framework_functions[click_manifest.framework]
 
     return transform_function(click_manifest)
 
-# takes easyprof manifest and converts it into apparmor profiles
-# directory is the output directory to place it into
-# returns a list of paths written to
-def to_profiles(easyprof_manifest, directory):
 
+# to_profiles(easyprof_manifest, directory)
+# - directory is the output directory to place it into
+# - returns a list of paths written to
+def to_profiles(easyprof_manifest, directory):
+    '''Convert manifest to AppArmor profile'''
     (easy_opts, easy_args) = apparmor.easyprof.parse_args(args=[])
 
-    profiles = apparmor.easyprof.parse_manifest(json.dumps(easyprof_manifest), easy_opts)
+    profiles = apparmor.easyprof.parse_manifest(json.dumps(easyprof_manifest),
+                                                easy_opts)
     files = []
 
     count = 0
@@ -435,9 +453,11 @@ def to_profiles(easyprof_manifest, directory):
 
     return files
 
-# returns a list of click links that are missing correlated profiles
+
+# get_missing_profiles(hooksdir, profilesdir)
+# - returns a list of click links that are missing correlated profiles
 def get_missing_profiles(hooksdir, profilesdir):
-    '''find click hooks that are missing profiles'''
+    '''Find click hooks that are missing profiles'''
     result = []
     for hook in os.listdir(hooksdir):
         name = AppName(clickname=hook)
@@ -445,9 +465,11 @@ def get_missing_profiles(hooksdir, profilesdir):
             result.append(name.clickname)
     return result
 
-# returns a list of profiles that are missing correlated click links
+
+# get_missing_clickhooks(hooksdir, profilesdir)
+# - returns a list of profiles that are missing correlated click links
 def get_missing_clickhooks(hooksdir, profilesdir):
-    '''find profiles that have had click packahes removed'''
+    '''Find profiles that have had click packages removed'''
     result = []
     for profile in os.listdir(profilesdir):
         try:
@@ -457,3 +479,34 @@ def get_missing_clickhooks(hooksdir, profilesdir):
         if not os.path.exists(os.path.join(hooksdir, name.clickname)):
             result.append(name.profilename)
     return result
+
+
+#
+# Defaults
+# FIXME: make these configurable via a configuration file
+#
+
+# These define the transformation funtions given a specific framework
+# definition in the ClickManifest file. This may need to grow more
+# complex depending on how the framework definition grows in click
+# packages
+framework_functions = {
+    "default": ubuntu_1310_transform,
+    "ubuntu-sdk-13.10": ubuntu_1310_transform,
+}
+
+# Ubuntu 13.10 tranformation function takes a click manifest json
+# structure as input and returns an aa-easyprof json manifest
+defaults_profile = {
+    'template': 'ubuntu-sdk',
+    'policy_version': '1.0',
+    'policy_vendor': 'ubuntu',
+    'policy_groups': list(),
+}
+
+# Required fields in click manifest
+required_click_fields = ["name", "version"]
+
+#
+# End defaults
+#
