@@ -23,6 +23,7 @@ import sys
 import tempfile
 import unittest
 
+
 class ClickState(object):
     def __init__(self, rootdir):
         self.rootdir = rootdir
@@ -40,43 +41,47 @@ class ClickState(object):
         j['name'] = name
         j['version'] = version
         j['hooks'] = dict()
-        j['title'] = "Some silly demo app called %s" %(name)
+        j['title'] = "Some silly demo app called %s" % (name)
         j['maintainer'] = 'Buggy McJerkerson <buggy@bad.soft.warez>'
         return j
 
     def _add_app_to_json(self, app):
         j = self.manifest_json
         j['hooks'][app] = dict()
-        j['hooks'][app]['apparmor'] = "apparmor/%s.json" %(app)
+        j['hooks'][app]['apparmor'] = "apparmor/%s.json" % (app)
         with open(self.click_manifest, "w") as f:
             json.dump(j, f, indent=2, separators=(',', ': '), sort_keys=True)
 
     def add_package(self, name, version, framework=None):
         self.package = name
         self.version = version
-        self.click_pkgdir = os.path.join(self.packages_tree, name, version, ".click", "info")
+        self.click_pkgdir = os.path.join(self.packages_tree, name, version,
+                                         ".click", "info")
         self.pkg_dir = os.path.join(self.packages_tree, name, version)
         os.makedirs(self.click_pkgdir)
         self.manifest_json = self._stub_json(name, version)
         if framework:
             self.manifest_json['framework'] = framework
-        self.click_manifest = os.path.join(self.click_pkgdir, "%s.manifest" %(name))
+        self.click_manifest = os.path.join(self.click_pkgdir, "%s.manifest" %
+                                           (name))
         with open(self.click_manifest, "w+") as f:
-            json.dump(self.manifest_json, f, indent=2, separators=(',', ': '), sort_keys=True)
+            json.dump(self.manifest_json, f, indent=2, separators=(',', ': '),
+                      sort_keys=True)
 
     def add_app(self, appname, manifest=None):
         os.mkdir(os.path.join(self.click_pkgdir, "apparmor"))
-        aa_json = os.path.join(self.click_pkgdir, "apparmor", "%s.json" %(appname))
+        aa_json = os.path.join(self.click_pkgdir, "apparmor", "%s.json" %
+                               (appname))
         self._add_app_to_json(appname)
 
         with open(aa_json, "w+") as f:
             if manifest:
                 f.write(manifest)
         os.symlink(aa_json, os.path.join(self.click_dir,
-                   "%s_%s_%s.json" %(self.package, appname, self.version)))
+                   "%s_%s_%s.json" % (self.package, appname, self.version)))
+
 
 class T(unittest.TestCase):
-
     def setUp(self):
         self.tmpdir = tempfile.mkdtemp(prefix="aa-click-manifest-")
         self.clickstate = ClickState(self.tmpdir)
@@ -91,20 +96,23 @@ class T(unittest.TestCase):
         ex_app = "com.ubuntu.developer.username.myapp"
         ex_name = "myapp"
         ex_vers = "0.1"
-        fname = "%s_%s_%s.json" %(ex_app, ex_name, ex_vers)
+        fname = "%s_%s_%s.json" % (ex_app, ex_name, ex_vers)
 
         (app, appname, version) = click.parse_manifest_name(fname)
 
-        self.assertEquals(ex_app, app, "expected app %s, got %s" %(ex_app, app))
-        self.assertEquals(ex_name, appname, "expected appname %s, got %s" %(ex_name, appname))
-        self.assertEquals(ex_vers, version, "expected version %s, got %s" %(ex_vers, version))
+        self.assertEquals(ex_app, app, "expected app %s, got %s" %
+                                       (ex_app, app))
+        self.assertEquals(ex_name, appname, "expected appname %s, got %s" %
+                                            (ex_name, appname))
+        self.assertEquals(ex_vers, version, "expected version %s, got %s" %
+                                            (ex_vers, version))
 
     def test_bad_manifest_name(self):
         '''test manifest name with not enough elements'''
         ex_app = "com.ubuntu.developer.username.myapp"
         ex_name = "myapp"
         ex_vers = "0.1"
-        fname = "%s_%s%s" %(ex_app, ex_name, ex_vers)
+        fname = "%s_%s%s" % (ex_app, ex_name, ex_vers)
 
         try:
             (app, appname, version) = click.parse_manifest_name(fname)
@@ -112,14 +120,14 @@ class T(unittest.TestCase):
             return
         except Exception:
             raise
-        raise Exception ("name %s should be invalid" %(fname))
+        raise Exception("name %s should be invalid" % (fname))
 
     def test_bad_manifest_name_2(self):
         '''test manifest name with too many elements'''
         ex_app = "com.ubuntu.developer.username.myapp"
         ex_name = "myapp"
         ex_vers = "0.1"
-        fname = "%s_%s_%s_err" %(ex_app, ex_name, ex_vers)
+        fname = "%s_%s_%s_err" % (ex_app, ex_name, ex_vers)
 
         try:
             (app, appname, version) = click.parse_manifest_name(fname)
@@ -127,17 +135,18 @@ class T(unittest.TestCase):
             return
         except Exception:
             raise
-        raise Exception ("name %s should be invalid" %(fname))
+        raise Exception("name %s should be invalid" % (fname))
 
     def test_click_name_to_profile(self):
         '''test click name conversion to profile name'''
 
         profile = "com.ubuntu.developer.username.myapp_myapp_0.3"
-        expected = "%s.json" %(profile)
-        orig = "click_%s" %(profile)
+        expected = "%s.json" % (profile)
+        orig = "click_%s" % (profile)
         app = click.AppName(profilename=orig)
         self.assertEquals(expected, app.clickname,
-                          "expected click name %s, got %s" %(expected, app.clickname))
+                          "expected click name %s, got %s" % (expected,
+                                                              app.clickname))
 
     def test_profile_name_to_click(self):
         '''test profile name conversion to click name'''
@@ -146,7 +155,8 @@ class T(unittest.TestCase):
         expected = "click_com.ubuntu.developer.username.myapp_myapp_0.3"
         app = click.AppName(orig)
         self.assertEquals(expected, app.profilename,
-                          "expected profile name %s, got %s" %(expected, app.profilename))
+                          "expected profile name %s, got %s" %
+                          (expected, app.profilename))
 
     def test_find_manifest_file(self):
         '''test being given a symlink and finding the main package manifest'''
@@ -154,18 +164,27 @@ class T(unittest.TestCase):
         c.add_package("package", "version")
         c.add_app("app")
 
-        (result, pkg_dir) = apparmor.click.get_package_manifest(os.path.join(c.click_dir, "package_app_version.json"), "package")
-        self.assertEquals(c.click_manifest, result, "Expected to get %s, got %s" %(c.click_manifest, result))
-        self.assertEquals(c.pkg_dir, pkg_dir, "Expected to get %s, got %s" %(c.pkg_dir, pkg_dir))
+        (result, pkg_dir) = apparmor.click.get_package_manifest(
+            os.path.join(c.click_dir, "package_app_version.json"), "package")
+        self.assertEquals(c.click_manifest, result,
+                          "Expected to get %s, got %s" %
+                          (c.click_manifest, result))
+        self.assertEquals(c.pkg_dir, pkg_dir, "Expected to get %s, got %s" %
+                                              (c.pkg_dir, pkg_dir))
 
     def test_parse_security_manifest(self):
         '''test being given a symlink and parsing the manifests'''
         c = self.clickstate
         c.add_package("com.ubuntu.developer.username.myapp", "0.1")
-        security_json='{  "policy_groups": [ "networking" ], "policy_version": "1.0" }'
+        security_json = '''{
+  "policy_groups": [ "networking" ],
+  "policy_version": "1.0"
+}'''
         c.add_app('sample-app', manifest=security_json)
 
-        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir, "com.ubuntu.developer.username.myapp_sample-app_0.1.json"))
+        n = "com.ubuntu.developer.username.myapp_sample-app_0.1.json"
+        nbase = n.strip(".json")
+        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir, n))
         easyprof_manifest = apparmor.click.transform(cm)
 
         expected = json.loads('''{
@@ -182,12 +201,17 @@ class T(unittest.TestCase):
       }
     }
   }
-}''' %(c.packages_tree))
-        self.assertEquals(expected, easyprof_manifest, "Expected to get %s, got %s" %(expected, easyprof_manifest))
+}''' % (c.packages_tree))
+        self.assertEquals(expected, easyprof_manifest,
+                          "Expected to get %s, got %s" %
+                          (expected, easyprof_manifest))
 
         # verify we're testing the json structures deeply
-        expected['profiles']['com.ubuntu.developer.username.myapp_sample-app_0.1']['template_variables']['BOGUS_VAR'] = 'bogus'
-        self.assertNotEquals(expected, easyprof_manifest, "Expected %s and %s to differ" %(expected, easyprof_manifest))
+        expected['profiles'][nbase]['template_variables']['BOGUS_VAR'] = \
+            'bogus'
+        self.assertNotEquals(expected, easyprof_manifest,
+                             "Expected %s and %s to differ" %
+                             (expected, easyprof_manifest))
 
     # the top level of the security manifest is not *supposed* to
     # be a single dict entry of the app, but apparently this happens.
@@ -196,15 +220,22 @@ class T(unittest.TestCase):
         '''test being given a symlink and parsing the manifests, leniently'''
         c = self.clickstate
         c.add_package("com.ubuntu.developer.username.myapp", "0.3")
-        security_json='{ "sample-app": { "policy_groups": [ "networking" ], "policy_version": "1.0" } }'
+        security_json = '''{
+  "sample-app": {
+    "policy_groups": [ "networking" ],
+    "policy_version": "1.0"
+  }
+}'''
         c.add_app('sample-app', manifest=security_json)
 
-        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir, "com.ubuntu.developer.username.myapp_sample-app_0.3.json"))
+        n = "com.ubuntu.developer.username.myapp_sample-app_0.3.json"
+        nbase = n.strip(".json")
+        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir, n))
         easyprof_manifest = apparmor.click.transform(cm)
 
         expected = json.loads('''{
   "profiles": {
-    "com.ubuntu.developer.username.myapp_sample-app_0.3": {
+    "%s": {
       "policy_groups": [ "networking" ],
       "policy_vendor": "ubuntu",
       "policy_version": "1.0",
@@ -216,22 +247,31 @@ class T(unittest.TestCase):
       }
     }
   }
-}''' %(c.packages_tree))
-        self.assertEquals(expected, easyprof_manifest, "Expected to get %s, got %s" %(expected, easyprof_manifest))
+}''' % (nbase, c.packages_tree))
+        self.assertEquals(expected, easyprof_manifest,
+                          "Expected to get %s, got %s" %
+                          (expected, easyprof_manifest))
 
     def test_parse_security_manifest_with_framework(self):
-        '''test being given a symlink and parsing the manifests w/framework setting'''
+        '''test being given a symlink and parsing the manifests w/framework
+           setting'''
         c = self.clickstate
-        c.add_package("com.ubuntu.developer.username.myapp", "0.1", framework='ubuntu-sdk-13.10')
-        security_json='{  "policy_groups": [ "networking" ], "policy_version": "1.0" }'
+        c.add_package("com.ubuntu.developer.username.myapp", "0.1",
+                      framework='ubuntu-sdk-13.10')
+        security_json = '''{
+  "policy_groups": [ "networking" ],
+  "policy_version": "1.0"
+}'''
         c.add_app('sample-app', manifest=security_json)
 
-        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir, "com.ubuntu.developer.username.myapp_sample-app_0.1.json"))
+        n = "com.ubuntu.developer.username.myapp_sample-app_0.1.json"
+        nbase = n.strip(".json")
+        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir, n))
         easyprof_manifest = apparmor.click.transform(cm)
 
         expected = json.loads('''{
   "profiles": {
-    "com.ubuntu.developer.username.myapp_sample-app_0.1": {
+    "%s": {
       "policy_groups": [ "networking" ],
       "policy_vendor": "ubuntu",
       "policy_version": "1.0",
@@ -243,39 +283,45 @@ class T(unittest.TestCase):
       }
     }
   }
-}''' %(c.packages_tree))
-        self.assertEquals(expected, easyprof_manifest, "Expected to get %s, got %s" %(expected, easyprof_manifest))
+}''' % (nbase, c.packages_tree))
+        self.assertEquals(expected, easyprof_manifest,
+                          "Expected to get %s, got %s" %
+                          (expected, easyprof_manifest))
 
     def test_parse_security_manifest_unknown_framework(self):
         '''test unknown framework raises exception'''
         c = self.clickstate
-        c.add_package("com.ubuntu.developer.username.myapp", "0.1", framework='unknown-sdk-13.10')
-        security_json='{  "policy_groups": [ "networking" ], "policy_version": "1.0" }'
+        c.add_package("com.ubuntu.developer.username.myapp", "0.1",
+                      framework='unknown-sdk-13.10')
+        security_json = '''{
+  "policy_groups": [ "networking" ],
+  "policy_version": "1.0"
+}'''
         c.add_app('sample-app', manifest=security_json)
 
+        n = "com.ubuntu.developer.username.myapp_sample-app_0.1.json"
         try:
-            cm = apparmor.click.ClickManifest(os.path.join(c.click_dir, "com.ubuntu.developer.username.myapp_sample-app_0.1.json"))
+            cm = apparmor.click.ClickManifest(os.path.join(c.click_dir, n))
             apparmor.click.transform(cm)
         except click.AppArmorException:
             return
         except Exception:
             raise
-        raise Exception ("Framework should be invalid")
+        raise Exception("Framework should be invalid")
 
     # the security policy is supposed to have a policy_groups entry even
     # if the list inside it is empty. However, I'm seeing click apps
     # without it so we'll accept it and move_on
-    # 
-    # 
     def test_parse_security_manifest_no_policy_groups(self):
         '''test being given a symlink and parsing the manifests, leniently'''
         c = self.clickstate
         package = "com.ubuntu.developer.username.yourapp"
         c.add_package(package, "0.3")
-        security_json='{ "policy_version": "1.0" }'
+        security_json = '{ "policy_version": "1.0" }'
         c.add_app('sample-app', manifest=security_json)
 
-        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir, "%s_sample-app_0.3.json" %(package)))
+        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir,
+                                          "%s_sample-app_0.3.json" % package))
         easyprof_manifest = apparmor.click.transform(cm)
 
         expected = json.loads('''{
@@ -292,18 +338,22 @@ class T(unittest.TestCase):
       }
     }
   }
-}''' %(package, package, c.packages_tree))
-        self.assertEquals(expected, easyprof_manifest, "Expected to get %s, got %s" %(expected, easyprof_manifest))
+}''' % (package, package, c.packages_tree))
+        self.assertEquals(expected, easyprof_manifest,
+                          "Expected to get %s, got %s" %
+                          (expected, easyprof_manifest))
 
     def test_parse_security_manifest_no_entries(self):
-        '''test being given a symlink and parsing the manifests, no policy whatsoever'''
+        '''test being given a symlink and parsing the manifests, no policy
+           whatsoever'''
         c = self.clickstate
         package = "com.ubuntu.newbie.username.yourapp"
         c.add_package(package, "0.3")
-        security_json='{ }'
+        security_json = '{ }'
         c.add_app('sample-app', manifest=security_json)
 
-        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir, "%s_sample-app_0.3.json" %(package)))
+        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir,
+                                          "%s_sample-app_0.3.json" % package))
         easyprof_manifest = apparmor.click.transform(cm)
 
         expected = json.loads('''{
@@ -320,20 +370,28 @@ class T(unittest.TestCase):
       }
     }
   }
-}''' %(package, package, c.packages_tree))
-        self.assertEquals(expected, easyprof_manifest, "Expected to get %s, got %s" %(expected, easyprof_manifest))
+}''' % (package, package, c.packages_tree))
+        self.assertEquals(expected, easyprof_manifest,
+                          "Expected to get %s, got %s" % (expected,
+                                                          easyprof_manifest))
 
     def test_parse_security_manifest_unconfined(self):
-        '''test being given a symlink and parsing the manifests for an unconfined app'''
+        '''test being given a symlink and parsing the manifests for an
+           unconfined app'''
 
         c = self.clickstate
         appname = "com.ubuntu.developer.trusteddev.terminal"
         c.add_package(appname, "0.99.9~123")
-        security_json='{ "template": "unconfined", "policy_groups": [ ], "policy_version": "1.0" }'
+        security_json = '''{
+  "template": "unconfined",
+  "policy_groups": [ ],
+  "policy_version": "1.0"
+}'''
         c.add_app('0wnzered', manifest=security_json)
 
         cm = apparmor.click.ClickManifest(os.path.join(c.click_dir,
-                                "%s_0wnzered_0.99.9~123.json" %(appname)))
+                                          "%s_0wnzered_0.99.9~123.json" %
+                                          (appname)))
         easyprof_manifest = apparmor.click.transform(cm)
 
         expected = json.loads('''{
@@ -350,8 +408,10 @@ class T(unittest.TestCase):
       }
     }
   }
-}''' %(appname, appname, c.packages_tree))
-        self.assertEquals(expected, easyprof_manifest, "Expected to get %s, got %s" %(expected, easyprof_manifest))
+}''' % (appname, appname, c.packages_tree))
+        self.assertEquals(expected, easyprof_manifest,
+                          "Expected to get %s, got %s" % (expected,
+                                                          easyprof_manifest))
 
     def _test_bad_json_noname(self):
         '''test for missing name field'''
@@ -373,7 +433,7 @@ class T(unittest.TestCase):
             return
         except Exception:
             raise
-        raise Exception ("Framework should be invalid")
+        raise Exception("Framework should be invalid")
 
     def _test_bad_json_noversion(self):
         '''test for missing version field'''
@@ -395,7 +455,7 @@ class T(unittest.TestCase):
             return
         except Exception:
             raise
-        raise Exception ("Framework should be invalid")
+        raise Exception("Framework should be invalid")
 
     def _test_bad_json_nosecurity(self):
         '''test for missing security struct'''
@@ -414,7 +474,8 @@ class T(unittest.TestCase):
             return
         except Exception:
             raise
-        raise Exception ("Framework should be invalid")
+        raise Exception("Framework should be invalid")
+
 
 class AppArmorManifestSynchronization(unittest.TestCase):
     def setUp(self):
@@ -429,18 +490,23 @@ class AppArmorManifestSynchronization(unittest.TestCase):
     def test_two_equal_directories(self):
         '''test two equal directories'''
         c = self.clickstate
-        clicks = ["alpha_beta_gamma", "click_click_version", "wat_no-really_wat"]
+        clicks = ["alpha_beta_gamma", "click_click_version",
+                  "wat_no-really_wat"]
         for cname in clicks:
-            with open(os.path.join(c.click_dir, '%s.json' %(cname)), 'w+') as f:
+            with open(os.path.join(c.click_dir, '%s.json' %
+                      (cname)), 'w+') as f:
                 f.write('invalid json here')
-            with open(os.path.join(c.profiles_dir, 'click_%s' %(cname)), 'w+') as f:
-                f.write('profile %s { }' %(cname))
+            with open(os.path.join(c.profiles_dir, 'click_%s' %
+                                   (cname)), 'w+') as f:
+                f.write('profile %s { }' % (cname))
 
         expected = []
         result = click.get_missing_profiles(c.click_dir, c.profiles_dir)
-        self.assertEquals(expected, result, "Expected to get no profiles, got %s" %(result))
+        self.assertEquals(expected, result,
+                          "Expected to get no profiles, got %s" % (result))
         result = click.get_missing_clickhooks(c.click_dir, c.profiles_dir)
-        self.assertEquals(expected, result, "Expected to get no click hooks, got %s" %(result))
+        self.assertEquals(expected, result,
+                          "Expected to get no click hooks, got %s" % (result))
 
     def test_two_empty_directories_for_profiles(self):
         '''test two empty directories returns no new needed profiles'''
@@ -448,7 +514,8 @@ class AppArmorManifestSynchronization(unittest.TestCase):
 
         expected = []
         result = click.get_missing_profiles(c.click_dir, c.profiles_dir)
-        self.assertEquals(expected, result, "Expected to get no profiles, got %s" %(result))
+        self.assertEquals(expected, result,
+                          "Expected to get no profiles, got %s" % (result))
 
     def test_two_empty_directories_for_clicks(self):
         '''test two empty directories returns no removed click hooks'''
@@ -456,39 +523,51 @@ class AppArmorManifestSynchronization(unittest.TestCase):
 
         expected = []
         result = click.get_missing_clickhooks(c.click_dir, c.profiles_dir)
-        self.assertEquals(expected, result, "Expected to get no clickhooks, got %s" %(result))
+        self.assertEquals(expected, result,
+                          "Expected to get no clickhooks, got %s" % (result))
 
     def test_versus_empty_profiles_directory(self):
         '''test against empty profiles directory'''
         c = self.clickstate
-        clicks = ["alpha_beta_gamma.json", "click_click_version.json", "wat_no-really_wat.json"]
+        clicks = ["alpha_beta_gamma.json", "click_click_version.json",
+                  "wat_no-really_wat.json"]
         for cname in clicks:
             with open(os.path.join(c.click_dir, cname), 'w+') as f:
                 f.write('invalid json here')
 
         expected = set(clicks)
         result = set(click.get_missing_profiles(c.click_dir, c.profiles_dir))
-        self.assertEquals(expected, result, "Expected to get %s profiles, got %s" %(expected, result))
+        self.assertEquals(expected, result,
+                          "Expected to get %s profiles, got %s" % (expected,
+                                                                   result))
 
     def test_versus_empty_clicks_directory(self):
         '''test against empty clicks directory'''
         c = self.clickstate
-        clicks = ["alpha_beta_gamma", "click_click_version", "wat_no-really_wat"]
+        clicks = ["alpha_beta_gamma", "click_click_version",
+                  "wat_no-really_wat"]
         for cname in clicks:
-            with open(os.path.join(c.profiles_dir, 'click_%s' %(cname)), 'w+') as f:
-                f.write('profile %s { }' %(cname))
+            with open(os.path.join(c.profiles_dir, 'click_%s' %
+                                   (cname)), 'w+') as f:
+                f.write('profile %s { }' % (cname))
 
-        expected = set(["%s%s" %(AppName._CLICK_PREFIX, x) for x in clicks])
+        expected = set(["%s%s" % (AppName._CLICK_PREFIX, x) for x in clicks])
         result = set(click.get_missing_clickhooks(c.click_dir, c.profiles_dir))
-        self.assertEquals(expected, result, "Expected to get %s hooks, got %s" %(expected, result))
+        self.assertEquals(expected, result,
+                          "Expected to get %s hooks, got %s" % (expected,
+                                                                result))
 
     def test_two_unequal_directories(self):
         '''test two equal directories'''
         c = self.clickstate
-        expected_clicks = ['missing_click_profile.json', 'another-missing_click_profile.json']
-        expected_profiles = ['%sremoved_click_package' %(AppName._CLICK_PREFIX)]
-        clicks = ["alpha_beta_gamma.json", "click_click_version.json", "wat_no-really_wat.json"]
-        profiles = ["%s%s" %(AppName._CLICK_PREFIX, x[:-len('.json')]) for x in clicks]
+        expected_clicks = ['missing_click_profile.json',
+                           'another-missing_click_profile.json']
+        expected_profiles = ['%sremoved_click_package' %
+                             (AppName._CLICK_PREFIX)]
+        clicks = ["alpha_beta_gamma.json", "click_click_version.json",
+                  "wat_no-really_wat.json"]
+        profiles = ["%s%s" % (AppName._CLICK_PREFIX,
+                              x[:-len('.json')]) for x in clicks]
         clicks.extend(expected_clicks)
         profiles.extend(expected_profiles)
         for cname in clicks:
@@ -496,12 +575,17 @@ class AppArmorManifestSynchronization(unittest.TestCase):
                 f.write('invalid json here')
         for pname in profiles:
             with open(os.path.join(c.profiles_dir, pname), 'w+') as f:
-                f.write('profile %s { }' %(pname))
+                f.write('profile %s { }' % (pname))
 
         result = set(click.get_missing_profiles(c.click_dir, c.profiles_dir))
-        self.assertEquals(set(expected_clicks), result, "Expected to get '%s' missing profiles, got %s" %(set(expected_clicks), result))
+        self.assertEquals(set(expected_clicks), result,
+                          "Expected to get '%s' missing profiles, got %s" %
+                          (set(expected_clicks), result))
         result = set(click.get_missing_clickhooks(c.click_dir, c.profiles_dir))
-        self.assertEquals(set(expected_profiles), result, "Expected to get '%s' missing click hooks, got %s" %(set(expected_profiles), result))
+        self.assertEquals(set(expected_profiles), result,
+                          "Expected to get '%s' missing click hooks, got %s" %
+                          (set(expected_profiles), result))
+
 
 class AppArmorPolicyModificationTests(unittest.TestCase):
 
@@ -517,7 +601,8 @@ class AppArmorPolicyModificationTests(unittest.TestCase):
     def test_load_simple_policy(self):
         '''test basic load policy function'''
         policy = "profile invalid_policy_dont_use { }"
-        with tempfile.NamedTemporaryFile(prefix = "aa-clicktest-", delete=False) as profile:
+        with tempfile.NamedTemporaryFile(prefix="aa-clicktest-",
+                                         delete=False) as profile:
             profile.write(bytes(policy, 'utf-8'))
             name = profile.name
 
@@ -532,7 +617,8 @@ class AppArmorPolicyModificationTests(unittest.TestCase):
     def test_load_simple_policies(self):
         '''test basic load polices function'''
         policy = "profile invalid_policy_dont_use { }"
-        with tempfile.NamedTemporaryFile(prefix = "aa-clicktest-", delete=False) as profile:
+        with tempfile.NamedTemporaryFile(prefix="aa-clicktest-",
+                                         delete=False) as profile:
             profile.write(bytes(policy, 'utf-8'))
             name = profile.name
 
@@ -546,7 +632,8 @@ class AppArmorPolicyModificationTests(unittest.TestCase):
 
     def test_unload_simple_policy(self):
         policy = "profile invalid_policy_dont_use { }"
-        with tempfile.NamedTemporaryFile(prefix = "aa-clicktest-", delete=False) as profile:
+        with tempfile.NamedTemporaryFile(prefix="aa-clicktest-",
+                                         delete=False) as profile:
             profile.write(bytes(policy, 'utf-8'))
             name = profile.name
 
@@ -559,11 +646,13 @@ class AppArmorPolicyModificationTests(unittest.TestCase):
         os.remove(name)
 
     def test_unload_simple_policies(self):
-        policies = ['more_invalid_policy_%s' %(suffix) for suffix in ['blart', 'blort', 'blat']]
+        policies = ['more_invalid_policy_%s' % (suffix)
+                    for suffix in ['blart', 'blort', 'blat']]
         names = []
         for p in policies:
-            policy = "profile %s { }" %(p)
-            with tempfile.NamedTemporaryFile(prefix = "aa-clicktest-", delete=False) as profile:
+            policy = "profile %s { }" % (p)
+            with tempfile.NamedTemporaryFile(prefix="aa-clicktest-",
+                                             delete=False) as profile:
                 profile.write(bytes(policy, 'utf-8'))
                 names.append(profile.name)
 
@@ -584,10 +673,13 @@ if __name__ == '__main__':
     suite = unittest.TestSuite()
     suite.addTest(unittest.TestLoader().loadTestsFromTestCase(T))
     if os.geteuid() == 0:
-        suite.addTest(unittest.TestLoader().loadTestsFromTestCase(AppArmorPolicyModificationTests))
+        suite.addTest(unittest.TestLoader().loadTestsFromTestCase(
+                      AppArmorPolicyModificationTests))
     else:
-        print('Not running as root, skipping tests that load/unload AppArmor policy', file=sys.stderr)
-    suite.addTest(unittest.TestLoader().loadTestsFromTestCase(AppArmorManifestSynchronization))
+        print('Not running as root, skipping tests that load/unload ' +
+              'AppArmor policy', file=sys.stderr)
+    suite.addTest(unittest.TestLoader().loadTestsFromTestCase(
+                  AppArmorManifestSynchronization))
 
     rc = unittest.TextTestRunner(verbosity=2).run(suite)
 
